@@ -1,20 +1,9 @@
-// File_Mpega - Info for MPEG Audio files
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // A good start : http://www.codeproject.com/audio/MPEGAudioInfo.asp
@@ -102,6 +91,9 @@ const char* Mpega_Format_Profile_Layer[4]=
 #include "MediaInfo/Audio/File_Mpega.h"
 #include "ZenLib/BitStream.h"
 #include "ZenLib/Utils.h"
+#if MEDIAINFO_ADVANCED
+    #include "MediaInfo/MediaInfo_Config_MediaInfo.h"
+#endif //MEDIAINFO_ADVANCED
 using namespace ZenLib;
 //---------------------------------------------------------------------------
 
@@ -501,7 +493,7 @@ void File_Mpega::Streams_Finish()
     if (FrameInfo.PTS!=(int64u)-1 && FrameInfo.PTS>PTS_Begin)
     {
         Fill(Stream_Audio, 0, Audio_Duration, float64_int64s(((float64)(FrameInfo.PTS-PTS_Begin))/1000000));
-        if (Retrieve(Stream_Audio, 0, Audio_BitRate_Mode)==__T("CBR"))
+        if (Retrieve(Stream_Audio, 0, Audio_BitRate_Mode)==__T("CBR") && ID<4 && sampling_frequency<4)
         {
             int16u Samples;
             if (ID==3 && layer==3) //MPEG 1 layer 1
@@ -516,7 +508,7 @@ void File_Mpega::Streams_Finish()
         }
     }
 
-    if (FrameCount==0 && VBR_FileSize && Retrieve(Stream_Audio, 0, Audio_BitRate_Mode)==__T("CBR") && Mpega_SamplingRate[ID][sampling_frequency])
+    if (FrameCount==0 && VBR_FileSize && Retrieve(Stream_Audio, 0, Audio_BitRate_Mode)==__T("CBR") && ID<4 && layer<4 && sampling_frequency<4 && bitrate_index<16 && Mpega_SamplingRate[ID][sampling_frequency])
     {
         size_t Size=(Mpega_Coefficient[ID][layer]*Mpega_BitRate[ID][layer][bitrate_index]*1000/Mpega_SamplingRate[ID][sampling_frequency])*Mpega_SlotSize[layer];
         if (Size)
@@ -783,8 +775,6 @@ bool File_Mpega::Synchronize()
     }
 
     //Synched is OK
-    if (!Status[IsAccepted])
-        File__Tags_Helper::Accept("MPEG Audio");
     return true;
 }
 
@@ -842,6 +832,21 @@ bool File_Mpega::Demux_UnpacketizeContainer_Test()
     int8u bitrate_index0     =(CC1(Buffer+Buffer_Offset+2)>>4)&0x0F;
     int8u sampling_frequency0=(CC1(Buffer+Buffer_Offset+2)>>2)&0x03;
     int8u padding_bit0       =(CC1(Buffer+Buffer_Offset+2)>>1)&0x01;
+
+    if (Mpega_SamplingRate[ID][sampling_frequency]==0 || Mpega_Coefficient[ID][layer]==0 || Mpega_BitRate[ID][layer][bitrate_index]==0 || Mpega_SlotSize[layer]==0)
+        return true; //Synhro issue
+
+    #if MEDIAINFO_ADVANCED
+        if (Frame_Count && File_Demux_Unpacketize_StreamLayoutChange_Skip)
+        {
+            int8u mode0              =CC1(Buffer+Buffer_Offset+3)>>6;
+            if (sampling_frequency0!=sampling_frequency_Frame0 || Mpega_Channels[mode0]!=Mpega_Channels[mode_Frame0])
+            {
+                return true;
+            }
+        }
+    #endif //MEDIAINFO_ADVANCED
+
     Demux_Offset=Buffer_Offset+(Mpega_Coefficient[ID0][layer0]*Mpega_BitRate[ID0][layer0][bitrate_index0]*1000/Mpega_SamplingRate[ID0][sampling_frequency0]+(padding_bit0?1:0))*Mpega_SlotSize[layer0];
 
     if (Demux_Offset>Buffer_Size)
@@ -888,15 +893,33 @@ void File_Mpega::Header_Parse()
     }
 
     //Filling
-    int64u Size=(Mpega_Coefficient[ID][layer]*Mpega_BitRate[ID][layer][bitrate_index]*1000/Mpega_SamplingRate[ID][sampling_frequency]+(padding_bit?1:0))*Mpega_SlotSize[layer];
+    int64u Size = ((int64u)Mpega_Coefficient[ID][layer] * (int64u)Mpega_BitRate[ID][layer][bitrate_index] * 1000 / (int64u)Mpega_SamplingRate[ID][sampling_frequency] + (padding_bit ? 1 : 0)) * (int64u)Mpega_SlotSize[layer];
+
+    //Special case: tags is inside the last frame
+    if (File_Offset+Buffer_Offset+Size>=File_Size-File_EndTagSize)
+        Size=File_Size-File_EndTagSize-(File_Offset+Buffer_Offset);
+
     Header_Fill_Size(Size);
-    Header_Fill_Code(0, "audio_data");
+    Header_Fill_Code(0, "frame");
 
     //Filling error detection
     sampling_frequency_Count[sampling_frequency]++;
     mode_Count[mode]++;
 
     FILLING_BEGIN();
+        #if MEDIAINFO_DEMUX
+            #if MEDIAINFO_ADVANCED
+                if (!Frame_Count)
+                {
+                    File_Demux_Unpacketize_StreamLayoutChange_Skip=Config->File_Demux_Unpacketize_StreamLayoutChange_Skip_Get();
+                    if (File_Demux_Unpacketize_StreamLayoutChange_Skip)
+                    {
+                        sampling_frequency_Frame0=sampling_frequency;
+                        mode_Frame0=mode;
+                    }
+                }
+            #endif //MEDIAINFO_ADVANCED
+        #endif //MEDIAINFO_DEMUX
     FILLING_END();
 }
 
@@ -915,7 +938,7 @@ void File_Mpega::Data_Parse()
     }
 
     //Partial frame
-    if (Header_Size+Element_Size<(int64u)((Mpega_Coefficient[ID][layer]*Mpega_BitRate[ID][layer][bitrate_index]*1000/Mpega_SamplingRate[ID][sampling_frequency]+(padding_bit?1:0))*Mpega_SlotSize[layer]))
+    if (Header_Size + Element_Size<((int64u)Mpega_Coefficient[ID][layer] * (int64u)Mpega_BitRate[ID][layer][bitrate_index] * 1000 / (int64u)Mpega_SamplingRate[ID][sampling_frequency] + (padding_bit ? 1 : 0)) * (int64u)Mpega_SlotSize[layer])
     {
         Element_Name("Partial frame");
         Skip_XX(Element_Size,                                   "Data");
@@ -938,7 +961,7 @@ void File_Mpega::Data_Parse()
     //Counting
     if (File_Offset+Buffer_Offset+Element_Size==File_Size-File_EndTagSize)
         Frame_Count_Valid=Frame_Count; //Finish MPEG Audio frames in case of there are less than Frame_Count_Valid frames
-    if (Frame_Count==0)
+    if (Frame_Count==0 && Frame_Count_NotParsedIncluded==0)
         PTS_Begin=FrameInfo.PTS;
     Frame_Count++;
     Frame_Count_InThisBlock++;
@@ -976,10 +999,101 @@ void File_Mpega::Data_Parse()
         return;
     }
 
-    //Parsing
-    int16u main_data_end;
+    //error_check
     if (protection_bit)
+    {
+        Element_Begin1("error_check");
         Skip_B2(                                                "crc_check");
+        Element_End0();
+    }
+
+    //audio_data
+    Element_Begin1("audio_data");
+    switch (layer)
+    {
+        case 1 : //Layer 3
+                audio_data_Layer3();
+                break;
+        default: Skip_XX(Element_Size-Element_Offset,           "(data)");
+    }
+    Element_End0();
+
+    //MP3 Surround detection
+    for (int64u Element_Offset_S=Element_Offset; Element_Offset_S+4<Element_Size; Element_Offset_S++)
+    {
+        if ( Buffer[(size_t)(Buffer_Offset+Element_Offset_S  )]      ==0xCF
+         && (Buffer[(size_t)(Buffer_Offset+Element_Offset_S+1)]&0xF0)==0x30) //12 bits, 0xCF3x
+        {
+            int8u Surround_Size=((Buffer[(size_t)(Buffer_Offset+Element_Offset_S+1)]&0x0F)<<4)
+                              | ((Buffer[(size_t)(Buffer_Offset+Element_Offset_S+2)]&0xF0)>>4);
+            int16u CRC12       =((Buffer[(size_t)(Buffer_Offset+Element_Offset_S+2)]&0x0F)<<8)
+                              |   Buffer[(size_t)(Buffer_Offset+Element_Offset_S+3)];
+            if (Element_Offset_S+Surround_Size-4>Element_Size)
+                break;
+
+            //CRC
+            int16u CRC12_Calculated=0x0FFF;
+            int8u* Data=(int8u*)Buffer+(size_t)(Buffer_Offset+Element_Offset_S+4);
+            if (Element_Offset_S+Surround_Size+4>=Element_Size)
+                break;
+            for (int8u Surround_Pos=0; Surround_Pos<Surround_Size-4; Surround_Pos++)
+                CRC12_Calculated=0x0FFF & (((CRC12_Calculated<<8)&0xff00)^Mpega_CRC12_Table[((CRC12_Calculated>>4) ^ *Data++) & 0xff]);
+            if (CRC12_Calculated!=CRC12)
+                break;
+
+            //Parsing
+            Skip_XX(Element_Offset_S-Element_Offset,            "data");
+            BS_Begin();
+            Element_Begin1("Surround");
+            Skip_S2(12,                                         "Sync");
+            Skip_S1( 8,                                         "Size");
+            Skip_S2(12,                                         "CRC12");
+            BS_End();
+            Skip_XX(Surround_Size-4,                            "data");
+            Element_End0();
+
+            //Filling
+            Surround_Frames++;
+            break;
+        }
+    }
+
+    if (Element_Offset<Element_Size)
+        Skip_XX(Element_Size-Element_Offset,                    "next data");
+
+    FILLING_BEGIN();
+        //Filling
+        if (IsSub && BitRate_Count.size()>1 && !Encoded_Library.empty())
+            Frame_Count_Valid=Frame_Count;
+        if (!Status[IsAccepted])
+            File__Analyze::Accept("MPEG Audio");
+        if (!Status[IsFilled] && Frame_Count>=Frame_Count_Valid)
+        {
+            Fill("MPEG Audio");
+
+            //Jumping
+            if (!IsSub && MediaInfoLib::Config.ParseSpeed_Get()<1.0 && File_Offset+Buffer_Offset<File_Size/2)
+            {
+                File__Tags_Helper::GoToFromEnd(16*1024, "MPEG-A");
+                LastSync_Offset=(int64u)-1;
+                if (File_GoTo!=(int64u)-1)
+                    Open_Buffer_Unsynch();
+            }
+        }
+
+        //Detect Id3v1 tags inside a frame
+        if (!IsSub && File_Offset+Buffer_Offset+(size_t)Element_Size>File_Size-File_EndTagSize)
+        {
+            Open_Buffer_Unsynch();
+            File__Analyze::Data_GoTo(File_Size-File_EndTagSize, "Tags inside a frame, parsing the tags");
+        }
+    FILLING_END();
+}
+
+//---------------------------------------------------------------------------
+void File_Mpega::audio_data_Layer3()
+{
+    int16u main_data_end;
     BS_Begin();
     if (ID==3) //MPEG-1
         Get_S2 (9, main_data_end,                               "main_data_end");
@@ -1082,73 +1196,7 @@ void File_Mpega::Data_Parse()
         Element_End0();
     } //granules
     BS_End();
-
-    //MP3 Surround detection
-    for (int64u Element_Offset_S=Element_Offset; Element_Offset_S+4<Element_Size; Element_Offset_S++)
-    {
-        if ( Buffer[(size_t)(Buffer_Offset+Element_Offset_S  )]      ==0xCF
-         && (Buffer[(size_t)(Buffer_Offset+Element_Offset_S+1)]&0xF0)==0x30) //12 bits, 0xCF3x
-        {
-            int8u Surround_Size=((Buffer[(size_t)(Buffer_Offset+Element_Offset_S+1)]&0x0F)<<4)
-                              | ((Buffer[(size_t)(Buffer_Offset+Element_Offset_S+2)]&0xF0)>>4);
-            int16u CRC12       =((Buffer[(size_t)(Buffer_Offset+Element_Offset_S+2)]&0x0F)<<8)
-                              |   Buffer[(size_t)(Buffer_Offset+Element_Offset_S+3)];
-            if (Element_Offset_S+Surround_Size-4>Element_Size)
-                break;
-
-            //CRC
-            int16u CRC12_Calculated=0x0FFF;
-            int8u* Data=(int8u*)Buffer+(size_t)(Buffer_Offset+Element_Offset_S+4);
-            if (Element_Offset_S+Surround_Size+4>=Element_Size)
-                break;
-            for (int8u Surround_Pos=0; Surround_Pos<Surround_Size-4; Surround_Pos++)
-                CRC12_Calculated=0x0FFF & (((CRC12_Calculated<<8)&0xff00)^Mpega_CRC12_Table[((CRC12_Calculated>>4) ^ *Data++) & 0xff]);
-            if (CRC12_Calculated!=CRC12)
-                break;
-
-            //Parsing
-            Skip_XX(Element_Offset_S-Element_Offset,            "data");
-            BS_Begin();
-            Element_Begin1("Surround");
-            Skip_S2(12,                                         "Sync");
-            Skip_S1( 8,                                         "Size");
-            Skip_S2(12,                                         "CRC12");
-            BS_End();
-            Skip_XX(Surround_Size-4,                            "data");
-            Element_End0();
-
-            //Filling
-            Surround_Frames++;
-            break;
-        }
-    }
-
-    if (Element_Offset<Element_Size)
-        Skip_XX(Element_Size-Element_Offset,                    "data");
-
-    FILLING_BEGIN();
-        //Filling
-        if (IsSub && BitRate_Count.size()>1 && !Encoded_Library.empty())
-            Frame_Count_Valid=Frame_Count;
-        if (!Status[IsFilled] && Frame_Count>=Frame_Count_Valid)
-        {
-            Fill("MPEG Audio");
-
-            //Jumping
-            if (!IsSub && MediaInfoLib::Config.ParseSpeed_Get()<1.0)
-            {
-                File__Tags_Helper::GoToFromEnd(16*1024, "MPEG-A");
-                LastSync_Offset=(int64u)-1;
-            }
-        }
-
-        //Detect Id3v1 tags inside a frame
-        if (!IsSub && File_Offset+Buffer_Offset+(size_t)Element_Size>File_Size-File_EndTagSize)
-        {
-            Open_Buffer_Unsynch();
-            File__Analyze::Data_GoTo(File_Size-File_EndTagSize, "Tags inside a frame, parsing the tags");
-        }
-    FILLING_END();
+    //Skip_XX(Element_Size-main_data_end-Element_Offset,          "main_data");
 }
 
 //---------------------------------------------------------------------------
