@@ -474,7 +474,7 @@ void File_DvDif::Streams_Fill()
         {
             Fill(Stream_General, 0, General_Format_Commercial_IfAny, "DVCPRO HD");
             Fill(Stream_Video, 0, Video_Format_Commercial_IfAny, "DVCPRO HD");
-            Fill(Stream_Video, 0, Video_BitDepth, 10, 10, true); //MXF files say that DVCPRO HD are 10 bits, exact?
+            Clear(Stream_Video, 0, Video_BitDepth); //MXF files say that DVCPRO HD streams are 8 or 10 bits, exact?
         }
         else
         {
@@ -1552,14 +1552,14 @@ void File_DvDif::video_source()
 
     BS_Begin();
     //PC1
-    Skip_S1(4,                                                  "TVCH (tens of units, 09)");
-    Skip_S1(4,                                                  "TVCH (units, 09)");
+    Skip_S1(4,                                                  "TVCH (tens of units, 0-9)");
+    Skip_S1(4,                                                  "TVCH (units, 0-9)");
 
     //PC2
     Skip_SB(                                                    "B/W - Black and White"); //0=Black and White, 1=Color
     Skip_SB(                                                    "EN - Color Frames is not valid");
     Skip_S1(2,                                                  "CLF - Color frames id");
-    Skip_S1(4,                                                  "TVCH (hundreds of units, 09)");
+    Skip_S1(4,                                                  "TVCH (hundreds of units, 0-9)");
 
     //PC3
     Skip_S1(2,                                                  "SRC");
