@@ -1,21 +1,8 @@
-// File_Lxf - Info for LXF files
-// Copyright (C) 2006-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -142,6 +129,11 @@ File_Lxf::File_Lxf()
         Demux_EventWasSent_Accept_Specific=true;
     #endif //MEDIAINFO_DEMUX
 
+    //Streams
+    #if defined(MEDIAINFO_ANCILLARY_YES)
+        Ancillary=NULL;
+    #endif //defined(MEDIAINFO_ANCILLARY_YES)
+
     //Temp
     LookingForLastFrame=false;
     Stream_Count=0;
@@ -175,6 +167,32 @@ File_Lxf::~File_Lxf()
             delete Audios[Pos].Parsers[Pos2];
 }
 
+//***************************************************************************
+// Buffer - File header
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+bool File_Lxf::FileHeader_Begin()
+{
+    //Synchro
+    if (8>Buffer_Size)
+        return false;
+    if (Buffer[0]!=0x4C //"LEITCH"
+     || Buffer[1]!=0x45
+     || Buffer[2]!=0x49
+     || Buffer[3]!=0x54
+     || Buffer[4]!=0x43
+     || Buffer[5]!=0x48
+     || Buffer[6]!=0x00
+     || Buffer[7]!=0x00)
+    {
+        Reject();
+        return false;
+    }
+
+    return true;
+}
+
 //***************************************************************************
 // Streams management
 //***************************************************************************
@@ -223,6 +241,14 @@ void File_Lxf::Streams_Fill_PerStream(File__Analyze* Parser, stream_t Container_
     else
     {
         Merge(*Parser);
+
+        Ztring LawRating=Parser->Retrieve(Stream_General, 0, General_LawRating);
+        if (!LawRating.empty())
+            Fill(Stream_General, 0, General_LawRating, LawRating, true);
+        Ztring Title=Parser->Retrieve(Stream_General, 0, General_Title);
+        if (!Title.empty() && Retrieve(Stream_General, 0, General_Title).empty())
+            Fill(Stream_General, 0, General_Title, Title);
+
         #if MEDIAINFO_DEMUX
             if (Config->Demux_ForceIds_Get())
                 for (size_t StreamKind=Stream_General+1; StreamKind<Stream_Max; StreamKind++)
@@ -257,6 +283,13 @@ void File_Lxf::Streams_Finish()
     {
         Finish(Videos[2].Parsers[0]);
         Merge(*Videos[2].Parsers[0], Stream_Video, 0, 0);
+
+        Ztring LawRating=Videos[2].Parsers[0]->Retrieve(Stream_General, 0, General_LawRating);
+        if (!LawRating.empty())
+            Fill(Stream_General, 0, General_LawRating, LawRating, true);
+        Ztring Title=Videos[2].Parsers[0]->Retrieve(Stream_General, 0, General_Title);
+        if (!Title.empty() && Retrieve(Stream_General, 0, General_Title).empty())
+            Fill(Stream_General, 0, General_Title, Title);
     }
 
     if (Audios_Header.TimeStamp_End!=(int64u)-1 && Audios_Header.TimeStamp_Begin!=(int64u)-1 && Audios_Header.Duration_First!=(int64u)-1)
@@ -444,7 +477,7 @@ void File_Lxf::Read_Buffer_Continue()
     #if MEDIAINFO_DEMUX
         if (DemuxParser)
         {
-            Open_Buffer_Continue(DemuxParser, Buffer+Buffer_Offset, 0);
+            Open_Buffer_Continue(DemuxParser, Buffer+Buffer_Offset, 0, false);
             if (!Config->Demux_EventWasSent)
                 DemuxParser=NULL; //No more need of it
         }
@@ -712,7 +745,6 @@ void File_Lxf::Header_Parse()
                     {
                     int32u Size;
                     int8u Channels_Count=0;
-                    bitset<32> Channels;
 
                     if (Version==0)
                     {
@@ -730,7 +762,6 @@ void File_Lxf::Header_Parse()
                         {
                             bool Channel;
                             Get_TB(Channel,                     "Channel");
-                            Channels[Pos]=Channel;
                             if (Channel)
                                 Channels_Count++;
                         }
@@ -826,7 +857,7 @@ void File_Lxf::Data_Parse()
         if (Element_Code&0x000100 && (Element_Code&0xFF)==2) //Checking Video stream 2
         {
             Frame_Count++;
-            if (!Status[IsFilled] && ((Frame_Count>6 && Stream_Count==0) || Frame_Count>300)) //5 video frames for 1 Audio frame
+            if (!Status[IsFilled] && ((Frame_Count>6 && (Stream_Count==0 ||Config->ParseSpeed==0.0)) || Frame_Count>512)) //5 video frames for 1 Audio frame
             {
                 Fill("LXF");
                 if (MediaInfoLib::Config.ParseSpeed_Get()<1)
@@ -1366,6 +1397,7 @@ void File_Lxf::Audio_Stream(size_t Pos)
             File_SmpteSt0337* Parser=new File_SmpteSt0337;
             Parser->Container_Bits=SampleSize;
             Parser->Endianness='L';
+            Parser->Aligned=true;
 
             Audios[Pos].Parsers.push_back(Parser);
         }
@@ -1481,7 +1513,20 @@ void File_Lxf::Audio_Stream(size_t Pos)
     #endif //MEDIAINFO_DEMUX
     */
 
+    #if MEDIAINFO_DEMUX
+        #if MEDIAINFO_SEEK
+            if (SeekRequest==(int64u)-1)
+        #endif //MEDIAINFO_SEEK
+        {
+            Element_Code=0x200+Pos;
+            Frame_Count_NotParsedIncluded=float64_int64s(((float64)(Audios_Header.TimeStamp_End-Audios_Header.Duration))/TimeStamp_Rate*FrameRate);
+            Demux_Level=4; //Intermediate
+            Demux(Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)Audio_Sizes[Pos], ContentType_MainStream);
+        }
+    #endif //MEDIAINFO_DEMUX
+
     //Parsing
+    Frame_Count_NotParsedIncluded=float64_int64s(((float64)(Audios_Header.TimeStamp_End-Audios_Header.Duration))/TimeStamp_Rate*FrameRate);
     for (size_t Pos2=0; Pos2<Audios[Pos].Parsers.size(); Pos2++)
     {
         if (Audios[Pos].Parsers[Pos2]->FrameInfo.DTS==(int64u)-1 || !((FrameInfo.DUR/2>FrameInfo.DTS || Audios[Pos].Parsers[Pos2]->FrameInfo.DTS>=FrameInfo.DTS-FrameInfo.DUR/2) && Audios[Pos].Parsers[Pos2]->FrameInfo.DTS<FrameInfo.DTS+FrameInfo.DUR/2))
@@ -1554,6 +1599,7 @@ void File_Lxf::Video_Stream(size_t Pos)
         {
             Element_Code=0x100+Pos;
             Frame_Count_NotParsedIncluded=float64_int64s(((float64)(Videos_Header.TimeStamp_End-Videos_Header.Duration))/TimeStamp_Rate*FrameRate);
+            Demux_Level=2; //Container
             Demux(Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)Video_Sizes[Pos], ContentType_MainStream);
         }
     #endif //MEDIAINFO_DEMUX
@@ -1615,12 +1661,12 @@ void File_Lxf::Video_Stream_1()
             Element_Begin1("VANC line");
             if (Videos[1].Parsers.empty())
             {
-                File_Ancillary* Parser=new File_Ancillary;
-                Parser->InDecodingOrder=true;
-                Parser->WithChecksum=true;
-                Parser->MustSynchronize=true;
-                Open_Buffer_Init(Parser);
-                Videos[1].Parsers.push_back(Parser);
+                Ancillary=new File_Ancillary;
+                Ancillary->InDecodingOrder=true;
+                Ancillary->WithChecksum=true;
+                Ancillary->MustSynchronize=true;
+                Open_Buffer_Init(Ancillary);
+                Videos[1].Parsers.push_back(Ancillary);
                 Stream_Count++;
             }
             Videos[1].Parsers[0]->FrameInfo=FrameInfo;
@@ -1640,6 +1686,9 @@ void File_Lxf::Video_Stream_1()
         #endif
     }
     Skip_XX((Lines_Allocated-Lines_Used)*BytesPerLine,          "Unused lines");
+
+    if (Element_Offset<Element_Size)
+        Skip_XX(Element_Size-Element_Offset,                    "Unknown");
 }
 
 //---------------------------------------------------------------------------
@@ -1748,7 +1797,13 @@ void File_Lxf::Video_Stream_2()
             Videos[2].Parsers.push_back(new File_DvDif());
         #endif //MEDIAINFO_DVDIF_YES
         #ifdef MEDIAINFO_MPEGV_YES
-            Videos[2].Parsers.push_back(new File_Mpegv());
+        {
+            File_Mpegv* Parser=new File_Mpegv();
+            #if defined(MEDIAINFO_ANCILLARY_YES)
+                Parser->Ancillary=&Ancillary;
+            #endif //defined(MEDIAINFO_ANCILLARY_YES)
+            Videos[2].Parsers.push_back(Parser);
+        }
         #endif //MEDIAINFO_MPEGV_YES
         #ifdef MEDIAINFO_AVC_YES
             Videos[2].Parsers.push_back(new File_Avc());
