@@ -107,6 +107,15 @@
     #if !defined (MEDIAINFO_MPEGTS_DUPLICATE_NO) && !defined (MEDIAINFO_MPEGTS_DUPLICATE_YES)
         #define MEDIAINFO_MPEGTS_DUPLICATE_NO
     #endif
+    #if !defined (MEDIAINFO_READTHREAD_NO) && !defined (MEDIAINFO_READTHREAD_YES)
+        #define MEDIAINFO_READTHREAD_NO
+    #endif
+    #if !defined (MEDIAINFO_MD5_NO) && !defined (MEDIAINFO_MD5_YES)
+        #define MEDIAINFO_MD5_NO
+    #endif
+    #if !defined (MEDIAINFO_AES_NO) && !defined (MEDIAINFO_AES_YES)
+        #define MEDIAINFO_AES_NO
+    #endif
 #endif
 
 //---------------------------------------------------------------------------
@@ -151,6 +160,16 @@
         #define MEDIAINFO_MACROBLOCKS 1
     #endif
 #endif
+#if !defined(MEDIAINFO_AES)
+    #if defined(MEDIAINFO_AES_NO) && defined(MEDIAINFO_AES_YES)
+        #undef MEDIAINFO_AES_NO //MEDIAINFO_AES_YES has priority
+    #endif
+    #if defined(MEDIAINFO_AES_NO)
+        #define MEDIAINFO_AES 0
+    #else
+        #define MEDIAINFO_AES 1
+    #endif
+#endif
 #if !defined(MEDIAINFO_NEXTPACKET)
     #if defined(MEDIAINFO_NEXTPACKET_NO) && defined(MEDIAINFO_NEXTPACKET_YES)
         #undef MEDIAINFO_NEXTPACKET_NO //MEDIAINFO_NEXTPACKET_YES has priority
@@ -191,6 +210,16 @@
         #define MEDIAINFO_ADVANCED 1
     #endif
 #endif
+#if !defined(MEDIAINFO_ADVANCED2) //ADVANCED2 is for optional build during defualt build
+    #if defined(MEDIAINFO_ADVANCED2_NO) && defined(MEDIAINFO_ADVANCED2_YES)
+        #undef MEDIAINFO_ADVANCED2_NO //MEDIAINFO_ADVANCED2_YES has priority
+    #endif
+    #if defined(MEDIAINFO_ADVANCED2_YES)
+        #define MEDIAINFO_ADVANCED2 1
+    #else
+        #define MEDIAINFO_ADVANCED2 0
+    #endif
+#endif
 #if !defined(MEDIAINFO_MD5)
     #if defined(MEDIAINFO_MD5_NO) && defined(MEDIAINFO_MD5_YES)
         #undef MEDIAINFO_MD5_NO //MEDIAINFO_MD5_YES has priority
@@ -227,6 +256,16 @@
         #define MEDIAINFO_IBI 1
     #endif
 #endif
+#if !defined(MEDIAINFO_READTHREAD)
+    #if defined(MEDIAINFO_READTHREAD_NO) && defined(MEDIAINFO_READTHREAD_YES)
+        #undef MEDIAINFO_READTHREAD_NO //MEDIAINFO_READTHREAD_YES has priority
+    #endif
+    #if defined(MEDIAINFO_READTHREAD_NO) || !defined(WINDOWS) //Currently supported only on Windows TODO: add support of non Windows OS
+        #define MEDIAINFO_READTHREAD 0
+    #else
+        #define MEDIAINFO_READTHREAD 1
+    #endif
+#endif
 
 //***************************************************************************
 // Precise configuration
@@ -278,6 +317,9 @@
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_REFERENCES_NO) && !defined(MEDIAINFO_REFERENCES_YES)
     #define MEDIAINFO_REFERENCES_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_AAF_NO) && !defined(MEDIAINFO_AAF_YES)
+    #define MEDIAINFO_AAF_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_ANCILLARY_NO) && !defined(MEDIAINFO_ANCILLARY_YES)
     #define MEDIAINFO_ANCILLARY_YES
 #endif
@@ -290,6 +332,9 @@
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_CDXA_NO) && !defined(MEDIAINFO_CDXA_YES)
     #define MEDIAINFO_CDXA_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_DASHMPD_NO) && !defined(MEDIAINFO_DASHMPD_YES)
+    #define MEDIAINFO_DASHMPD_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_DCP_NO) && !defined(MEDIAINFO_DCP_YES)
     #define MEDIAINFO_DCP_YES
 #endif
@@ -311,6 +356,9 @@
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_GXF_NO) && !defined(MEDIAINFO_GXF_YES)
     #define MEDIAINFO_GXF_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_HDSF4M_NO) && !defined(MEDIAINFO_HDSF4M_YES)
+    #define MEDIAINFO_HDSF4M_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_HLS_NO) && !defined(MEDIAINFO_HLS_YES)
     #define MEDIAINFO_HLS_YES
 #endif
@@ -362,6 +410,9 @@
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_PMP_NO) && !defined(MEDIAINFO_PMP_YES)
     #define MEDIAINFO_PMP_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_PTX_NO) && !defined(MEDIAINFO_PTX_YES)
+    #define MEDIAINFO_PTX_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_RIFF_NO) && !defined(MEDIAINFO_RIFF_YES)
     #define MEDIAINFO_RIFF_YES
 #endif
@@ -413,6 +464,9 @@
 #if !defined(MEDIAINFO_VIDEO_NO) && !defined(MEDIAINFO_DIRAC_NO) && !defined(MEDIAINFO_DIRAC_YES)
     #define MEDIAINFO_DIRAC_YES
 #endif
+#if !defined(MEDIAINFO_VIDEO_NO) && !defined(MEDIAINFO_FFV1_NO) && !defined(MEDIAINFO_FFV1_YES)
+    #define MEDIAINFO_FFV1_YES
+#endif
 #if !defined(MEDIAINFO_VIDEO_NO) && !defined(MEDIAINFO_FLIC_NO) && !defined(MEDIAINFO_FLIC_YES)
     #define MEDIAINFO_FLIC_YES
 #endif
@@ -425,6 +479,9 @@
 #if !defined(MEDIAINFO_VIDEO_NO) && !defined(MEDIAINFO_HEVC_NO) && !defined(MEDIAINFO_HEVC_YES)
     #define MEDIAINFO_HEVC_YES
 #endif
+#if !defined(MEDIAINFO_VIDEO_NO) && !defined(MEDIAINFO_HUFFYUV_NO) && !defined(MEDIAINFO_HUFFYUV_YES)
+    #define MEDIAINFO_HUFFYUV_YES
+#endif
 #if !defined(MEDIAINFO_VIDEO_NO) && !defined(MEDIAINFO_LAGARITH_NO) && !defined(MEDIAINFO_LAGARITH_YES)
     #define MEDIAINFO_LAGARITH_YES
 #endif
@@ -518,6 +575,9 @@
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_MPEGA_NO) && !defined(MEDIAINFO_MPEGA_YES)
     #define MEDIAINFO_MPEGA_YES
 #endif
+#if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_OPENMG_NO) && !defined(MEDIAINFO_OPENMG_YES)
+    #define MEDIAINFO_OPENMG_YES
+#endif
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_OPUS_NO) && !defined(MEDIAINFO_OPUS_YES)
     #define MEDIAINFO_OPUS_YES
 #endif
@@ -599,6 +659,9 @@
 #if !defined(MEDIAINFO_TEXT_NO) && !defined(MEDIAINFO_KATE_NO) && !defined(MEDIAINFO_KATE_YES)
     #define MEDIAINFO_KATE_YES
 #endif
+#if !defined(MEDIAINFO_TEXT_NO) && !defined(MEDIAINFO_PDF_NO) && !defined(MEDIAINFO_PDF_YES)
+    #define MEDIAINFO_PDF_YES
+#endif
 #if !defined(MEDIAINFO_TEXT_NO) && !defined(MEDIAINFO_PGS_NO) && !defined(MEDIAINFO_PGS_YES)
     #define MEDIAINFO_PGS_YES
 #endif
@@ -626,9 +689,15 @@
 
 //---------------------------------------------------------------------------
 // Image
+#if !defined(MEDIAINFO_IMAGE_NO) && !defined(MEDIAINFO_ARRIRAW_NO) && !defined(MEDIAINFO_ARRIRAW_YES)
+    #define MEDIAINFO_ARRIRAW_YES
+#endif
 #if !defined(MEDIAINFO_IMAGE_NO) && !defined(MEDIAINFO_BMP_NO) && !defined(MEDIAINFO_BMP_YES)
     #define MEDIAINFO_BMP_YES
 #endif
+#if !defined(MEDIAINFO_IMAGE_NO) && !defined(MEDIAINFO_DDS_NO) && !defined(MEDIAINFO_DDS_YES)
+    #define MEDIAINFO_DDS_YES
+#endif
 #if !defined(MEDIAINFO_IMAGE_NO) && !defined(MEDIAINFO_DPX_NO) && !defined(MEDIAINFO_DPX_YES)
     #define MEDIAINFO_DPX_YES
 #endif
