@@ -1,20 +1,9 @@
-/* MediaInfoDLL - All info about media files, for DLL
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Public DLL interface implementation
@@ -128,7 +117,7 @@
 #endif
 
 /*-------------------------------------------------------------------------*/
-#if defined (_WIN32) || defined (WIN32)
+#if defined(_WIN32) || defined(WIN32)
     #ifdef _UNICODE
         #define MEDIAINFODLL_NAME L"MediaInfo.dll"
     #else //_UNICODE
@@ -137,16 +126,21 @@
 #elif defined(__APPLE__) && defined(__MACH__)
     #define MEDIAINFODLL_NAME "libmediainfo.0.dylib"
     #define __stdcall
+    #ifdef __cplusplus
+        #include <new> //for size_t
+    #else /* __cplusplus */
+        #include <stddef.h> //for size_t
+    #endif /* __cplusplus */
 #else
     #define MEDIAINFODLL_NAME "libmediainfo.so.0"
     #define __stdcall
-#endif //!defined(_WIN32) || defined (WIN32)
+#endif //!defined(_WIN32) || defined(WIN32)
 
 /*-------------------------------------------------------------------------*/
 /*Char types                                                               */
 #undef  __T
 #define __T(__x)    __T(__x)
-#if defined(UNICODE) || defined (_UNICODE)
+#if defined(UNICODE) || defined(_UNICODE)
     typedef wchar_t MediaInfo_Char;
     #undef  __T
     #define __T(__x) L ## __x
@@ -237,10 +231,14 @@ extern "C"
 #ifdef MEDIAINFO_GLIBC
     #include <gmodule.h>
     static GModule* MediaInfo_Module = NULL;
-#elif defined (_WIN32) || defined (WIN32)
+#elif defined(_WIN32) || defined(WIN32)
     #include <windows.h>
-    static HMODULE  MediaInfo_Module = NULL;
+    static HMODULE MediaInfo_Module = NULL;
 #else
+    #ifdef MACOSX
+        #include <CoreFoundation/CFBundle.h>
+    #endif
+
     #include <dlfcn.h>
     static void* MediaInfo_Module = NULL;
 #endif
@@ -253,7 +251,7 @@ extern "C"
 #define MEDIAINFOLIST_ASSIGN(_Name,_Name2) \
     if (!g_module_symbol (MediaInfo_Module, "MediaInfoList" MEDIAINFO_Ansi "_" _Name2, (gpointer*)&MediaInfoList_##_Name)) \
         Errors++;
-#elif defined (_WIN32) || defined (WIN32)
+#elif defined(_WIN32) || defined(WIN32)
 #define MEDIAINFO_ASSIGN(_Name,_Name2) \
     MediaInfo_##_Name=(MEDIAINFO_##_Name)GetProcAddress(MediaInfo_Module, "MediaInfo" MEDIAINFO_Ansi "_" _Name2); \
     if (MediaInfo_##_Name==NULL) Errors++;
@@ -340,10 +338,38 @@ extern "C"
     /* Load library */
     #ifdef MEDIAINFO_GLIBC
         MediaInfo_Module = g_module_open(MEDIAINFODLL_NAME, G_MODULE_BIND_LAZY);
-    #elif defined (_WIN32) || defined (WIN32)
+    #elif defined(_WIN32) || defined(WIN32)
         MediaInfo_Module = LoadLibrary(MEDIAINFODLL_NAME);
     #else
-        MediaInfo_Module = dlopen(MEDIAINFODLL_NAME, RTLD_LAZY);
+        #ifdef MACOSX
+            MediaInfo_Module = dlopen("@executable_path/" MEDIAINFODLL_NAME, RTLD_LAZY);
+            if (!MediaInfo_Module)
+            {
+                CFBundleRef mainBundle = CFBundleGetMainBundle();
+
+                // get full app path and delete app name
+                CFURLRef app_url = CFBundleCopyExecutableURL(mainBundle);
+                CFURLRef app_path_url = CFURLCreateCopyDeletingLastPathComponent(NULL, app_url);
+
+                CFStringRef app_path = CFURLCopyFileSystemPath(app_path_url, kCFURLPOSIXPathStyle);
+
+                CFMutableStringRef mut_app_path = CFStringCreateMutableCopy(NULL, NULL, app_path);
+                CFStringAppend(mut_app_path, CFSTR("/"));
+                CFStringAppend(mut_app_path, CFSTR(MEDIAINFODLL_NAME));
+                CFStringEncoding encodingMethod = CFStringGetSystemEncoding();
+                const char *fullPath = CFStringGetCStringPtr(mut_app_path, encodingMethod);
+
+                MediaInfo_Module = dlopen(fullPath, RTLD_LAZY);
+
+                CFRelease(app_url);
+                CFRelease(app_path_url);
+                CFRelease(app_path);
+                CFRelease(mut_app_path);
+            }
+        #endif /* MACOSX*/
+
+        if (!MediaInfo_Module)
+            MediaInfo_Module = dlopen(MEDIAINFODLL_NAME, RTLD_LAZY);
         if (!MediaInfo_Module)
             MediaInfo_Module = dlopen("./" MEDIAINFODLL_NAME, RTLD_LAZY);
         if (!MediaInfo_Module)
@@ -391,7 +417,7 @@ extern "C"
         // Unload DLL with errors
         #ifdef MEDIAINFO_GLIBC
             g_module_close(MediaInfo_Module);
-        #elif defined (_WIN32) || defined (WIN32)
+        #elif defined(_WIN32) || defined(WIN32)
             FreeLibrary(MediaInfo_Module);
         #else
             dlclose(MediaInfo_Module);
@@ -420,7 +446,7 @@ extern "C"
 
     #ifdef MEDIAINFO_GLIBC
         g_module_close(MediaInfo_Module);
-    #elif defined (_WIN32) || defined (WIN32)
+    #elif defined(_WIN32) || defined(WIN32)
         FreeLibrary(MediaInfo_Module);
     #else
         dlclose(MediaInfo_Module);
@@ -451,7 +477,7 @@ namespace MediaInfoDLL
     //MediaInfo_Char types
 #undef  __T
 #define __T(__x)    __T(__x)
-#if defined(UNICODE) || defined (_UNICODE)
+#if defined(UNICODE) || defined(_UNICODE)
     typedef wchar_t Char;
     #undef  __T
     #define __T(__x) L ## __x
@@ -517,13 +543,13 @@ namespace MediaInfoDLL
 
     const String Unable_Load_DLL = __T("Unable to load ")MEDIAINFODLL_NAME;
 #define MEDIAINFO_TEST_VOID \
-    if (!IsReady()) return
+    if (!MediaInfo_Module) {MediaInfoDLL_Load(); if (!MediaInfo_Module) return;}
 #define MEDIAINFO_TEST_INT \
-    if (!IsReady()) return 0
+    if (!MediaInfo_Module) {MediaInfoDLL_Load(); if (!MediaInfo_Module) return 0;}
 #define MEDIAINFO_TEST_STRING \
-    if (!IsReady()) return Unable_Load_DLL
+    if (!MediaInfo_Module) {MediaInfoDLL_Load(); if (!MediaInfo_Module) return Unable_Load_DLL;}
 #define MEDIAINFO_TEST_STRING_STATIC \
-    if (!MediaInfo_Module) return Unable_Load_DLL
+    if (!MediaInfo_Module) {MediaInfoDLL_Load(); if (!MediaInfo_Module) return Unable_Load_DLL;}
 
     //---------------------------------------------------------------------------
     class MediaInfo
@@ -555,8 +581,6 @@ namespace MediaInfoDLL
         size_t        State_Get() {MEDIAINFO_TEST_INT; return MediaInfo_State_Get(Handle);};
         size_t        Count_Get(stream_t StreamKind, size_t StreamNumber = (size_t) - 1)  {MEDIAINFO_TEST_INT; return MediaInfo_Count_Get(Handle, (MediaInfo_stream_C)StreamKind, StreamNumber);};
 
-        bool IsReady() {return (Handle && MediaInfo_Module) ? true : false;}
-
     private :
         void* Handle;
     };
@@ -584,8 +608,6 @@ namespace MediaInfoDLL
         size_t        Count_Get(size_t FilePos, stream_t StreamKind, size_t StreamNumber = (size_t) - 1)  {MEDIAINFO_TEST_INT; return MediaInfoList_Count_Get(Handle, FilePos, (MediaInfo_stream_C)StreamKind, StreamNumber);};
         size_t        Count_Get()  {MEDIAINFO_TEST_INT; return MediaInfoList_Count_Get_Files(Handle);};
 
-        bool IsReady() {return (Handle && MediaInfo_Module) ? true : false;}
-
     private :
         void* Handle;
     };
