@@ -162,33 +162,21 @@ bool File::Open (const tstring &File_Name_, access_t Access)
             DWORD dwDesiredAccess, dwShareMode, dwCreationDisposition;
             switch (Access)
             {
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                case Access_Read         : dwDesiredAccess=IsWin9X_Fast()?GENERIC_READ:FILE_READ_DATA; dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_EXISTING; break;
+                case Access_Read         : dwDesiredAccess=FILE_READ_DATA; dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_EXISTING;   break;
                 case Access_Write        : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
-                case Access_Read_Write   : dwDesiredAccess=(IsWin9X_Fast()?GENERIC_READ:FILE_READ_DATA)|GENERIC_WRITE;   dwShareMode=0; dwCreationDisposition=OPEN_ALWAYS;   break;
+                case Access_Read_Write   : dwDesiredAccess=FILE_READ_DATA|GENERIC_WRITE;   dwShareMode=0; dwCreationDisposition=OPEN_ALWAYS;                    break;
                 case Access_Write_Append : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
-                #else // ZENLIB_NO_WIN9X_SUPPORT
-                case Access_Read         : dwDesiredAccess=FILE_READ_DATA; dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_EXISTING; break;
-                case Access_Write        : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
-                case Access_Read_Write   : dwDesiredAccess=FILE_READ_DATA|GENERIC_WRITE;   dwShareMode=0; dwCreationDisposition=OPEN_ALWAYS;   break;
-                case Access_Write_Append : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
                 default                  : dwDesiredAccess=0;               dwShareMode=0;                                 dwCreationDisposition=0;             break;
             }
 
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    File_Handle=CreateFileA(File_Name.To_Local().c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
+                File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
             #else
                 File_Handle=CreateFile(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
             #endif //UNICODE
             if (File_Handle==INVALID_HANDLE_VALUE)
             {
-                //Sometime the file is locked for few milliseconds, we try again later
+                //Sometimes the file is locked for few milliseconds, we try again later
                 DWORD dw = GetLastError();
                 if (dw!=ERROR_FILE_NOT_FOUND)
                 {
@@ -204,12 +192,7 @@ bool File::Open (const tstring &File_Name_, access_t Access)
                     */
                     Sleep(1000);
                     #ifdef UNICODE
-                        #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                        if (IsWin9X_Fast())
-                            File_Handle=CreateFileA(Ztring(File_Name).To_Local().c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
-                        else
-                        #endif //ZENLIB_NO_WIN9X_SUPPORT
-                            File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
+                        File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
                     #else
                         File_Handle=CreateFile(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
                     #endif //UNICODE
@@ -291,12 +274,7 @@ bool File::Create (const Ztring &File_Name_, bool OverWrite)
             }
 
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    File_Handle=CreateFileA(File_Name.To_Local().c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
+                File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
             #else
                 File_Handle=CreateFile(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
             #endif //UNICODE
@@ -305,12 +283,7 @@ bool File::Create (const Ztring &File_Name_, bool OverWrite)
                 //Sometime the file is locked for few milliseconds, we try again later
                 Sleep(3000);
                 #ifdef UNICODE
-                    #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                    if (IsWin9X_Fast())
-                        File_Handle=CreateFileA(File_Name.To_Local().c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
-                    else
-                    #endif //ZENLIB_NO_WIN9X_SUPPORT
-                        File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
+                    File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
                 #else
                     File_Handle=CreateFile(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
                 #endif //UNICODE
@@ -443,11 +416,11 @@ bool File::Truncate (int64u Offset)
         return false;
 
     #ifdef ZENLIB_USEWX
-        return false; Not supported
+        return false; //Not supported
     #else //ZENLIB_USEWX
         #ifdef ZENLIB_STANDARD
             #if defined(WINDOWS)
-                return false; //No supported
+                return false; //Not supported
             #else //defined(WINDOWS)
                 //Need to close the file, use truncate, reopen it
                 if (Offset==(int64u)-1)
@@ -522,13 +495,9 @@ bool File::GoTo (int64s Position_ToMove, move_t MoveMethod)
             ((fstream*)File_Handle)->seekg((streamoff)Position_ToMove, dir);
             return !((fstream*)File_Handle)->fail();
         #elif defined WINDOWS
-            LARGE_INTEGER GoTo; GoTo.QuadPart=Position_ToMove;
-            //return SetFilePointerEx(File_Handle, GoTo, NULL, MoveMethod)!=0; //Not on win9X
-            GoTo.LowPart=SetFilePointer(File_Handle, GoTo.LowPart, &GoTo.HighPart, MoveMethod);
-            if (GoTo.LowPart==INVALID_SET_FILE_POINTER && GetLastError()!=NO_ERROR)
-                return false;
-            else
-                return true;
+            LARGE_INTEGER GoTo;
+            GoTo.QuadPart=Position_ToMove;
+            return SetFilePointerEx(File_Handle, GoTo, NULL, MoveMethod)!=0;
         #endif
     #endif //ZENLIB_USEWX
 }
@@ -593,28 +562,21 @@ int64u File::Size_Get()
             File_Size=lseek(File_Handle, 0, SEEK_END);
             lseek(File_Handle, CurrentPos, SEEK_SET);
             */
-            streampos CurrentPos=((fstream*)File_Handle)->tellg();
-            if (CurrentPos!=(streampos)-1)
+            fstream::pos_type CurrentPos=((fstream*)File_Handle)->tellg();
+            if (CurrentPos!=(fstream::pos_type)-1)
             {
                 ((fstream*)File_Handle)->seekg(0, ios_base::end);
                 Size=((fstream*)File_Handle)->tellg();
-                ((fstream*)File_Handle)->seekg(CurrentPos, ios_base::beg);
+                ((fstream*)File_Handle)->seekg(CurrentPos);
             }
             else
                 Size=(int64u)-1;
         #elif defined WINDOWS
-            #ifdef ZENLIB_NO_WIN9X_SUPPORT
                 LARGE_INTEGER x = {0};
                 BOOL bRet = ::GetFileSizeEx(File_Handle, &x);
                 if (bRet == FALSE)
                     return (int64u)-1;
                 Size=x.QuadPart;
-            #else 
-                DWORD High;DWORD Low=GetFileSize(File_Handle, &High);
-                if (Low==INVALID_FILE_SIZE && GetLastError()!=NO_ERROR)
-                    return (int64u)-1;
-                Size=0x100000000ULL*High+Low;
-            #endif //ZENLIB_NO_WIN9X_SUPPORT
         #endif
         return Size;
     #endif //ZENLIB_USEWX
@@ -719,7 +681,7 @@ Ztring File::Modified_Get()
             int Result=stat(File_Name.To_Local().c_str(), &Stat);
             if (Result<0)
                 return __T(""); //Error
-            Ztring Time; Time.Date_From_Seconds_1970(Stat.st_mtime);
+            Ztring Time; Time.Date_From_Seconds_1970((int64s)Stat.st_mtime);
             return Time;
         #elif defined WINDOWS
             FILETIME TimeFT;
@@ -846,13 +808,7 @@ bool File::Exists(const Ztring &File_Name)
             if (File_Name.find(__T('*'))!=std::string::npos || (File_Name.find(__T("\\\\?\\"))!=0 && File_Name.find(__T('?'))!=std::string::npos) || (File_Name.find(__T("\\\\?\\"))==0 && File_Name.find(__T('?'), 4)!=std::string::npos))
                 return false;
             #ifdef UNICODE
-                DWORD FileAttributes;
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    FileAttributes=GetFileAttributesA(File_Name.To_Local().c_str());
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    FileAttributes=GetFileAttributesW(File_Name.c_str());
+                DWORD FileAttributes=GetFileAttributesW(File_Name.c_str());
             #else
                 DWORD FileAttributes=GetFileAttributes(File_Name.c_str());
             #endif //UNICODE
@@ -871,12 +827,7 @@ bool File::Copy(const Ztring &Source, const Ztring &Destination, bool OverWrite)
             return false;
         #elif defined WINDOWS
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    return CopyFileA(Source.To_Local().c_str(), Destination.To_Local().c_str(), !OverWrite)!=0;
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    return CopyFileW(Source.c_str(), Destination.c_str(), !OverWrite)!=0;
+                return CopyFileW(Source.c_str(), Destination.c_str(), !OverWrite)!=0;
             #else
                 return CopyFile(Source.c_str(), Destination.c_str(), !OverWrite)!=0;
             #endif //UNICODE
@@ -898,12 +849,7 @@ bool File::Move(const Ztring &Source, const Ztring &Destination, bool OverWrite)
             return !std::rename(Source.To_Local().c_str(), Destination.To_Local().c_str());
         #elif defined WINDOWS
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    return MoveFileA(Source.To_Local().c_str(), Destination.To_Local().c_str())!=0;
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    return MoveFileW(Source.c_str(), Destination.c_str())!=0;
+                return MoveFileW(Source.c_str(), Destination.c_str())!=0;
             #else
                 return MoveFile(Source.c_str(), Destination.c_str())!=0;
             #endif //UNICODE
@@ -925,12 +871,7 @@ bool File::Delete(const Ztring &File_Name)
             #endif //UNICODE
         #elif defined WINDOWS
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    return DeleteFileA(File_Name.To_Local().c_str())!=0;
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    return DeleteFileW(File_Name.c_str())!=0;
+                return DeleteFileW(File_Name.c_str())!=0;
             #else
                 return DeleteFile(File_Name.c_str())!=0;
             #endif //UNICODE
